@@ -1,8 +1,8 @@
 """Some simple authentication examples."""
+
 from __future__ import annotations
 
 from collections import Counter
-from typing import cast
 
 from jira import JIRA
 from jira.client import ResultList
@@ -24,9 +24,7 @@ myself = jira.myself()
 props = jira.application_properties()
 
 # Find all issues reported by the admin
-# Note: we cast() for mypy's benefit, as search_issues can also return the raw json !
-#   This is if the following argument is used: `json_result=True`
-issues = cast(ResultList[Issue], jira.search_issues("assignee=admin"))
+issues: ResultList[Issue] = jira.search_issues("assignee=admin")
 
 # Find the top three projects containing issues reported by admin
 top_three = Counter([issue.fields.project.key for issue in issues]).most_common(3)
