@@ -114,7 +114,7 @@ def parse_errors(resp: Response) -> list[str]:
         # Sometimes this is present but empty
         error_messages = resp_data["errorMessages"]
         if len(error_messages) > 0:
-            if isinstance(error_messages, (list, tuple)):
+            if isinstance(error_messages, list | tuple):
                 parsed_errors = list(error_messages)
             else:
                 parsed_errors = [error_messages]
@@ -180,7 +180,7 @@ class ResilientSession(Session):
         prepared_kwargs["headers"] = request_headers
 
         data = original_kwargs.get("data", None)
-        if isinstance(data, dict):
+        if isinstance(data, dict) and data:
             # mypy ensures we don't do this,
             # but for people subclassing we should preserve old behaviour
             prepared_kwargs["data"] = json.dumps(data)
