@@ -11,6 +11,7 @@ import logging
 import re
 import time
 from typing import TYPE_CHECKING, Any, cast
+from urllib.parse import ParseResult, urlparse, urlunparse
 
 from requests import Response
 from requests.structures import CaseInsensitiveDict
@@ -292,6 +293,24 @@ class Resource:
         options.update({"path": path})
         return self._base_url.format(**options)
 
+    def _validate_self_self_url(self) -> None:
+        """In the case of a proxy, use the configured option server URL."""
+        if getattr(self, "self", None):
+            self.self: str
+            self_parsed = urlparse(self.self)
+            server_parsed = urlparse(self._options["server"])
+            if self_parsed.netloc != server_parsed.netloc:
+                self.self = urlunparse(
+                    ParseResult(
+                        scheme=server_parsed.scheme,
+                        netloc=server_parsed.netloc,
+                        path=self_parsed.path,
+                        params=self_parsed.params,
+                        query=self_parsed.query,
+                        fragment=self_parsed.fragment,
+                    )
+                )
+
     def update(
         self,
         fields: dict[str, Any] | None = None,
@@ -326,6 +345,7 @@ class Resource:
         else:
             querystring = ""
 
+        self._validate_self_self_url()
         r = self._session.put(self.self + querystring, data=json.dumps(data))
         if "autofix" in self._options and r.status_code == 400:
             user = None
@@ -420,6 +440,7 @@ class Resource:
         Returns:
             Optional[Response]: Returns None if async
         """
+        self._validate_self_self_url()
         if self._options["async"]:
             # FIXME: mypy doesn't think this should work
             if not hasattr(self._session, "_async_jobs"):
@@ -887,7 +908,7 @@ class Issue(Resource):
         """Delete this issue from the server.
 
         Args:
-            deleteSubtasks (bool): True to also delete subtasks. If any are present the Issue won't be deleted (Default: ``True``)
+            deleteSubtasks (bool): True to also delete subtasks. If any are present the Issue won't be deleted (Default: ``False``)
         """
         super().delete(params={"deleteSubtasks": deleteSubtasks})
 
@@ -1504,7 +1525,7 @@ class AgileResource(Resource):
         session: ResilientSession,
         raw: dict[str, Any] | None = None,
     ):
-        self.self = None
+        self.self = ""
 
         Resource.__init__(self, path, options, session, self.AGILE_BASE_URL)
         if raw:
