@@ -337,6 +337,22 @@ class IssueTests(JiraTestCase):
         issue.update(fields=fields)
         self.assertEqual(issue.fields.labels, ["testLabel"])
 
+    def test_update_label_with_proxy(self):
+        issue = self.jira.create_issue(
+            summary="Test issue for updating labels",
+            project=self.project_b,
+            description="Label testing",
+            issuetype=self.test_manager.CI_JIRA_ISSUE,
+        )
+
+        labelarray = ["testLabel"]
+        fields = {"labels": labelarray}
+        # This simulates when your Jira server is behind a proxy
+        # The self address returned will be different from the configured server
+        issue.self = f"https://foo.bar/jira/rest/api/2/issue/{issue.id}"
+        issue.update(fields=fields)
+        self.assertEqual(issue.fields.labels, ["testLabel"])
+
     def test_update_with_bad_label(self):
         issue = self.jira.create_issue(
             summary="Test issue for updating bad labels",
@@ -373,6 +389,20 @@ class IssueTests(JiraTestCase):
         issue.delete()
         self.assertRaises(JIRAError, self.jira.issue, key)
 
+    def test_delete_with_proxy(self):
+        issue = self.jira.create_issue(
+            summary="Test issue created",
+            project=self.project_b,
+            description="Not long for this world",
+            issuetype=self.test_manager.CI_JIRA_ISSUE,
+        )
+        key = issue.key
+        # This simulates when your Jira server is behind a proxy
+        # The self address returned will be different from the configured server
+        issue.self = f"https://foo.bar/jira/rest/api/2/issue/{issue.id}"
+        issue.delete()
+        self.assertRaises(JIRAError, self.jira.issue, key)
+
     def test_createmeta(self):
         meta = self.jira.createmeta()
         proj = find_by_key(meta["projects"], self.project_b)
