@@ -1,8 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Iterator
 from contextlib import contextmanager
 from functools import lru_cache
-from typing import Iterator
 
 import pytest as pytest
 
@@ -22,6 +22,7 @@ class SprintTests(JiraTestCase):
         self.board_name = f"board-{uniq}"
         self.sprint_name = f"sprint-{uniq}"
         self.filter_name = f"filter-{uniq}"
+        self.sprint_goal = f"goal-{uniq}"
 
         self.board, self.filter = self._create_board_and_filter()
 
@@ -76,6 +77,36 @@ class SprintTests(JiraTestCase):
             assert sprint.state.upper() == "FUTURE"
         # THEN: the sprint .delete() is called successfully
 
+    def test_create_with_goal(self):
+        # GIVEN: The board, sprint name, and goal
+        # WHEN: we create the sprint
+        sprint = self.jira.create_sprint(
+            self.sprint_name, self.board.id, goal=self.sprint_goal
+        )
+        # THEN: we create the sprint with a goal
+        assert isinstance(sprint.id, int)
+        assert sprint.name == self.sprint_name
+        assert sprint.goal == self.sprint_goal
+
+    def test_update_sprint(self):
+        # GIVEN: The sprint ID
+        # WHEN: we update the sprint
+        sprint = self.jira.create_sprint(
+            self.sprint_name, self.board.id, goal=self.sprint_goal
+        )
+        assert isinstance(sprint.id, int)
+        assert sprint.name == self.sprint_name
+        assert sprint.goal == self.sprint_goal
+        # THEN: the name changes
+        updated_sprint = self.jira.update_sprint(
+            sprint.id,
+            "new_name",
+            state="future",
+            startDate="2015-04-11T15:22:00.000+10:00",
+            endDate="2015-04-20T01:22:00.000+10:00",
+        )
+        assert updated_sprint["name"] == "new_name"
+
     def test_add_issue_to_sprint(self):
         # GIVEN: The sprint
         with self._create_sprint() as sprint:
